==> surefire-3.0.0-source-release.zip: surefire-3.0.0/surefire-its/src/test/java/org/apache/maven/surefire/its/Surefire1602IT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.surefire.its;

import org.apache.maven.it.VerificationException;
import org.apache.maven.surefire.its.fixture.SurefireJUnit4IntegrationTestCase;
import org.apache.maven.surefire.its.fixture.SurefireLauncher;
import org.junit.Test;

/**
 * Test ability to specify a non canonical path as module root
 *
 * @author <a href="mailto:eolivelli@apache.org">Enrico Olivelli</a>
 */
public class Surefire1602IT extends SurefireJUnit4IntegrationTestCase {
    @Test
    public void nonCanonicalPath() throws VerificationException {
        SurefireLauncher launcher = unpack("/surefire-1602");
        launcher.executeInstall();
        launcher.addGoal("--file").addGoal("./integration-tests/pom.xml").executeTest();
        launcher.getSubProjectValidator("integration-tests").assertTestSuiteResults(1, 0, 0, 0);
    }
}

==> surefire-3.5.4-source-release.zip: surefire-3.5.4/surefire-its/src/test/java/org/apache/maven/surefire/its/Surefire1602IT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.surefire.its;

import org.apache.maven.shared.verifier.VerificationException;
import org.apache.maven.surefire.its.fixture.SurefireJUnit4IntegrationTestCase;
import org.apache.maven.surefire.its.fixture.SurefireLauncher;
import org.junit.Test;

/**
 * Test ability to specify a non canonical path as module root
 *
 * @author <a href="mailto:eolivelli@apache.org">Enrico Olivelli</a>
 */
public class Surefire1602IT extends SurefireJUnit4IntegrationTestCase {
    @Test
    public void nonCanonicalPath() throws VerificationException {
        SurefireLauncher launcher = unpack("/surefire-1602");
        launcher.setLogFileName("log-install.txt");
        launcher.executeInstall();
        launcher.reset();

        launcher.setLogFileName("log-test.txt");
        launcher.addGoal("--file").addGoal("./integration-tests/pom.xml").executeTest();
        launcher.getSubProjectValidator("integration-tests").assertTestSuiteResults(1, 0, 0, 0);
    }
}
